Module Name:    src
Committed By:   andvar
Date:           Fri Jul 12 22:31:41 UTC 2024

Modified Files:
        src/sys/arch/sparc64/sparc64: clock.c
        src/usr.sbin/tpctl: main.c

Log Message:
s/calibrarion/calibration/ in debug message and comments.


To generate a diff of this commit:
cvs rdiff -u -r1.123 -r1.124 src/sys/arch/sparc64/sparc64/clock.c
cvs rdiff -u -r1.7 -r1.8 src/usr.sbin/tpctl/main.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/sparc64/sparc64/clock.c
diff -u src/sys/arch/sparc64/sparc64/clock.c:1.123 src/sys/arch/sparc64/sparc64/clock.c:1.124
--- src/sys/arch/sparc64/sparc64/clock.c:1.123	Fri May 29 12:30:41 2020
+++ src/sys/arch/sparc64/sparc64/clock.c	Fri Jul 12 22:31:40 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: clock.c,v 1.123 2020/05/29 12:30:41 rin Exp $ */
+/*	$NetBSD: clock.c,v 1.124 2024/07/12 22:31:40 andvar Exp $ */
 
 /*
  * Copyright (c) 1992, 1993
@@ -55,7 +55,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: clock.c,v 1.123 2020/05/29 12:30:41 rin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: clock.c,v 1.124 2024/07/12 22:31:40 andvar Exp $");
 
 #include "opt_multiprocessor.h"
 
@@ -308,7 +308,7 @@ timerattach(device_t parent, device_t se
 	 */
 
 #ifdef DEBUG
-	printf("Delay calibrarion....\n");
+	printf("Delay calibration....\n");
 #endif
 	for (timerblurb = 1; timerblurb > 0; timerblurb++) {
 		volatile int discard;

Index: src/usr.sbin/tpctl/main.c
diff -u src/usr.sbin/tpctl/main.c:1.7 src/usr.sbin/tpctl/main.c:1.8
--- src/usr.sbin/tpctl/main.c:1.7	Mon Jul 16 01:04:47 2018
+++ src/usr.sbin/tpctl/main.c	Fri Jul 12 22:31:40 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: main.c,v 1.7 2018/07/16 01:04:47 christos Exp $	*/
+/*	$NetBSD: main.c,v 1.8 2024/07/12 22:31:40 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2002 TAKEMRUA Shin
@@ -49,7 +49,7 @@
 
 #ifndef lint
 #include <sys/cdefs.h>
-__RCSID("$NetBSD: main.c,v 1.7 2018/07/16 01:04:47 christos Exp $");
+__RCSID("$NetBSD: main.c,v 1.8 2024/07/12 22:31:40 andvar Exp $");
 #endif /* not lint */
 
 void load_data(const char *, struct tpctl_data *);
@@ -125,7 +125,7 @@ main(int argc, char *argv[])
 		/* NOTREACHED */
 	}
 
 	/* load calibrarion parameters from specified file */
 	load_data(data_file, &data);
 
 	/* open touch panel device and initialize touch panel routines */
@@ -138,7 +138,7 @@ main(int argc, char *argv[])
 	pref = search_data(&data, tp.id);
 	if (opt_forceupdate || pref == NULL) {
 		/* if the parameters wasn't found or '-f' options was 
-		   specified, do 'calibrarion' */
+		   specified, do 'calibration' */
 		struct wsmouse_calibcoords coords;
 
 		/* draw cursors and collect samples */
@@ -162,7 +162,7 @@ main(int argc, char *argv[])
 	if (tp_setcalibcoords(&tp, pref) < 0)
 		errx(EXIT_FAILURE, "can't set samples");
 
 	/* save calibrarion parameters from specified file */
 	if (!opt_noupdate)
 		save_data(data_file, &data);
 	/* dispose data */
@@ -173,7 +173,7 @@ main(int argc, char *argv[])
 }
 
 /*
  * load calibrarion parameters from specified file
  *
  * return:	none (it won't return if some error occurs)
  */
@@ -215,7 +215,7 @@ load_data(const char *data_file, struct 
 }
 
 /*
  * save calibrarion parameters to specified file
  *
  * return:	none (it won't return if some error occurs)
  */
@@ -125,7 +125,7 @@ main(int argc, char *argv[])
 	}
 
-	/* load calibrarion parameters from specified file */
+	/* load calibration parameters from specified file */
 	load_data(data_file, &data);
 
@@ -162,7 +162,7 @@ main(int argc, char *argv[])
 		errx(EXIT_FAILURE, "can't set samples");
 
-	/* save calibrarion parameters from specified file */
+	/* save calibration parameters from specified file */
 	if (!opt_noupdate)
 		save_data(data_file, &data);
@@ -173,7 +173,7 @@ main(int argc, char *argv[])
 
 /*
- * load calibrarion parameters from specified file
+ * load calibration parameters from specified file
  *
  * return:	none (it won't return if some error occurs)
@@ -215,7 +215,7 @@ load_data(const char *data_file, struct 
 
 /*
- * save calibrarion parameters to specified file
+ * save calibration parameters to specified file
  *
  * return:	none (it won't return if some error occurs)

Reply via email to